sequencer property
a string representation of a hexadecimal value used to determine event sequence, only used with PUTs and DELETEs
Implementation
String? sequencer;
a string representation of a hexadecimal value used to determine event sequence, only used with PUTs and DELETEs
String? sequencer;